@@ -129,6 +129,8 @@ static gboolean validity_check (              GtkTreeModel *model,
     const gchar *with_entry_str = gtk_entry_get_text (GTK_ENTRY (ks.fr_entry_fields[WITH_ENTRY]));
           gboolean *no_invalid_replacements = &(fr_data->no_invalid_replacements);
 
+    gchar *not_executed_str = _("Find and replace action not executed.");
+
     g_autofree gchar *menu_element_txt, 
                      *type_txt;
 
@@ -146,12 +148,12 @@ static gboolean validity_check (              GtkTreeModel *model,
         gtk_tree_model_get (model, iter, TS_VALUE, &value, -1);
         if (G_UNLIKELY ((new_value = compute_hypothetical_replacement (value)) && 
                         !streq_any (new_value, "yes", "no", NULL))) {
-			// Translation note: Do not translate "enabled", "yes", "no"
+            // Translation note: Do not translate "enabled", "yes", "no"
             g_autofree gchar *err_msg = g_strdup_printf (_("An <b>\"enabled\"</b> option can't have a value other than "
                                                            "<b>\"yes\"</b> or <b>\"no\"</b> and thus a replacement of "
                                                            "\"%s\" with \"%s\" won't be done.\n\n"
-                                                           "<b><span foreground='%s'>Find and replace action not executed.</span></b>"), 
-                                                         value, with_entry_str, ks.red_hue);
+                                                           "<b><span foreground='%s'>%s</span></b>"), 
+                                                         value, with_entry_str, ks.red_hue, not_executed_str);
             show_errmsg (err_msg);
 
             *no_invalid_replacements = FALSE;
@@ -177,10 +179,8 @@ static gboolean validity_check (              GtkTreeModel *model,
                 if (G_UNLIKELY (STREQ (menu_ids_loop->data, new_menu_id_txt) && !STREQ (new_menu_id_txt, menu_id_txt))) {
                     g_autofree gchar *err_msg = g_strdup_printf (_("The menu ID <b>\"%1$s\"</b> won't be replaced with <b>\"%2$s\"</b>, "
                                                                    "because this would create a double menu ID.\n\n"
-                                                                   "<b><span foreground='%3$s'>"
-                                                                   "Find and replace action not executed."
-                                                                   "</span></b>"), 
-                                                                 menu_id_txt, new_menu_id_txt, ks.red_hue);
+                                                                   "<b><span foreground='%3$s'>%4$s</span></b>"), 
+                                                                 menu_id_txt, new_menu_id_txt, ks.red_hue, not_executed_str);
 
                     show_errmsg (err_msg);
 
@@ -214,13 +214,12 @@ static gboolean validity_check (              GtkTreeModel *model,
                                                                                "would replace both menu IDs "
                                                                                "<b>\"%1$s\"</b> and <b>\"%2$s\"</b> with <b>\"%3$s\"</b>, "
                                                                                "thus creating a double menu ID.\n\n"
-                                                                               "<b><span foreground='%4$s'>"
-                                                                               "Find and replace action not executed."
-                                                                               "</span></b>"), 
+                                                                               "<b><span foreground='%4$s'>%5$s</span></b>"), 
                                                                              menu_IDs_before_and_after_pair1[1], 
                                                                              menu_IDs_before_and_after_pair2[1], 
                                                                              menu_IDs_before_and_after_pair1[0], 
-                                                                             ks.red_hue);
+                                                                             ks.red_hue, 
+                                                                             not_executed_str);
                                 show_errmsg (err_msg);
 
                                 *no_invalid_replacements = FALSE;
@@ -270,7 +269,7 @@ static gboolean validity_check (              GtkTreeModel *model,
                 }
 
                 g_autofree gchar *err_msg = g_strdup_printf ("%s\n\n<b><span foreground='%s'>%s</span></b>", 
-                                                             substr, ks.red_hue, _("Find and replace action not executed."));
+                                                             substr, ks.red_hue, not_executed_str);
 
                 show_errmsg (err_msg);
 
@@ -297,10 +296,8 @@ static gboolean validity_check (              GtkTreeModel *model,
                 g_autofree gchar *err_msg = g_strdup_printf (_("The execute instruction of the pipe menu <b>\"%1$s\"</b> "
                                                                "with the menu ID <b>\"%2$s\"</b> won't be deleted, "
                                                                "because this would render this pipe menu useless.\n\n"
-                                                               "<b><span foreground='%3$s'>"
-                                                               "Find and replace action not executed."
-                                                               "</span></b>"), 
-                                                             menu_element_txt, menu_id_txt, ks.red_hue);
+                                                               "<b><span foreground='%3$s'>%4$s</span></b>"), 
+                                                             menu_element_txt, menu_id_txt, ks.red_hue, not_executed_str);
 
                 show_errmsg (err_msg);
 
@@ -505,9 +502,9 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
         replacements_done_label_txt = (fr_data.replacements_done_cnt) ? 
                                       ((fr_data.replacements_done_cnt < 10) ? 
-									   // Translation note: The translation should work for %s getting replaced with phrases ranging from "once" to "nine times"
+                                       // Translation note: The translation should work for %s getting replaced with phrases ranging from "once" to "nine times"
                                        g_strdup_printf (_("Search key replaced %s."), _(small_numbers_spelled_out[(fr_data.replacements_done_cnt) - 1])) : 
-									   // Translation note: The translation should work for %i getting replaced with positive numbers
+                                       // Translation note: The translation should work for %i getting replaced with positive numbers
                                        g_strdup_printf (ngettext ("Search key replaced %i times.", "Search key replaced %i times.", fr_data.replacements_done_cnt), fr_data.replacements_done_cnt)) : 
                                        g_strdup (_("Search key not found."));
         gtk_label_set_text (GTK_LABEL (ks.fr_replacements_done_label), replacements_done_label_txt);
@@ -560,18 +557,18 @@ void show_find_and_replace_dialog (void)
     GtkWidget *special_options_grid = gtk_grid_new ();
     enum { FR_REPLACE_LABEL, FR_IN_LABEL, FR_WITH_LABEL, NUMBER_OF_FR_LABEL_FIELDS };
     const gchar *fr_label_txts[] = { // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
-	                                 _("<b>Replace: </b>"), 
-									 // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
-									 // A translation of "In" as "Where" would also work
-									 _("<b>In:</b>"), 
-									 // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
+                                     _("<b>Replace: </b>"), 
+                                     // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
+                                     // A translation of "In" as "Where" would also work
+                                     _("<b>In:</b>"), 
+                                     // Translation note: This is for a "Search and Replace" window, in the context of "Replace something in x with y"
                                      // A translation of "With" as "With what" would also work
-									 _("<b>With:</b>") };
+                                     _("<b>With:</b>") };
     GtkWidget *fr_labels[NUMBER_OF_FR_LABEL_FIELDS] = { gtk_label_new (NULL), gtk_label_new (NULL), gtk_label_new (NULL) };
     const gchar *special_options_txts[] = { // This is for a search functionality. A translation of "case sensitive" or "distinguish between uppercase and lowercase letters" would also work.
-	                                        _("Match Case"), 
-	                                        _("Regular Expression (PCRE)"), 
-											_("Whole Word") };
+                                            _("Match Case"), 
+                                            _("Regular Expression (PCRE)"), 
+                                            _("Whole Word") };
 
     gint8 columns_cnt;
 
